class Tour < ActiveRecord::Base
  attr_accessible :body, :name, :position, :published, :speed, :direction, :control_display, :start_position, :loop, :auto_start,
    # Slug, I18n e tags
    :slug, :locale, :translations_attributes, :tag_list,
    # Paperclip
    :tour, :tour_content_type, :tour_file_name, :tour_file_size
  # Taggings
  acts_as_taggable

  has_many :marcations

  has_attached_file :tour,
                    :styles => {
                      :thumb      => "560x180#"
                    },
                    :convert_options => { :all => '-auto-orient -quality 70 -interlace Plane' }
                    # :processors => [:thumbnail, :compression]

  # URL amigáveis através do :name
  extend FriendlyId
  friendly_id :name, use: [:slugged, :history]

  # Escopos
  scope :visible, where("published = ?", true)
  scope :recents, lambda{ |limit = 10| visible.order("datetime desc").limit(limit)}
  scope :ordained, lambda{ |limit = 10| visible.order("position asc").limit(limit)}

  # Contador de visitas
  is_visitable accept_ip: true

  # Translate
  translates :name, :body
  accepts_nested_attributes_for :translations

  class Translation
    attr_accessible :locale, :name, :body
  end
  def translations_attributes=(attributes)
    new_translations = attributes.values.reduce({}) do |new_values, translation|
      new_values.merge! translation.delete("locale") => translation
    end
    set_translations new_translations
  end
end
